@@ -300,7 +300,7 @@ class Scraper(Component):
 
 
     @Component._login_required
-    def get_user_posts(self:'InstaClient', username:str, count:Optional[int]=30, deep_scrape:Optional[bool]=False, callback_frequency:int=100, callback=None, **callback_args) -> Optional[Union[List[str], List[Profile]]]:
+    def get_user_posts(self:'InstaClient', username:str, count:Optional[int]=30, deep_scrape:Optional[bool]=False, callback_frequency:int=100, callback=None, **callback_args) -> Optional[Union[List[str], List[Post]]]:
         """Get a list of posts of a specified user.
 
         Args:
@@ -1148,7 +1148,10 @@ class Scraper(Component):
                 result = requests.get(url, headers=headers)
 
             try:
-                return result.json()
+                if result.json():
+                    return result.json()
+                else:
+                    use_driver = True
             except:
                 use_driver = True
         
